@@ -41,13 +41,13 @@ init_longVersion(void)
      * VAX C can't concatenate strings in the preprocessor.
      */
     strcpy(longVersion, VIM_VERSION_LONG_DATE);
-#ifdef BUILD_DATE
+#  ifdef BUILD_DATE
     strcat(longVersion, BUILD_DATE);
-#else
+#  else
     strcat(longVersion, __DATE__);
     strcat(longVersion, " ");
     strcat(longVersion, __TIME__);
-#endif
+#  endif
     strcat(longVersion, ")");
 }
 
@@ -60,11 +60,11 @@ init_longVersion(void)
     if (longVersion != NULL)
 	return;
 
-#ifdef BUILD_DATE
+#  ifdef BUILD_DATE
     char *date_time = BUILD_DATE;
-#else
+#  else
     char *date_time = __DATE__ " " __TIME__;
-#endif
+#  endif
     char *msg = _("%s (%s, compiled %s)");
     size_t len = strlen(msg)
 	+ strlen(VIM_VERSION_LONG_ONLY)
@@ -684,11 +684,11 @@ static char *(features[]) =
 	"-X11",
 # endif
 #endif
-# ifdef FEAT_XATTR
+#ifdef FEAT_XATTR
 	"+xattr",
-# else
+#else
 	"-xattr",
-# endif
+#endif
 #ifdef FEAT_XFONTSET
 	"+xfontset",
 #else
@@ -734,6 +734,156 @@ static char *(features[]) =
 
 static int included_patches[] =
 {   /* Add new patch number below this line */
+/**/
+    2125,
+/**/
+    2124,
+/**/
+    2123,
+/**/
+    2122,
+/**/
+    2121,
+/**/
+    2120,
+/**/
+    2119,
+/**/
+    2118,
+/**/
+    2117,
+/**/
+    2116,
+/**/
+    2115,
+/**/
+    2114,
+/**/
+    2113,
+/**/
+    2112,
+/**/
+    2111,
+/**/
+    2110,
+/**/
+    2109,
+/**/
+    2108,
+/**/
+    2107,
+/**/
+    2106,
+/**/
+    2105,
+/**/
+    2104,
+/**/
+    2103,
+/**/
+    2102,
+/**/
+    2101,
+/**/
+    2100,
+/**/
+    2099,
+/**/
+    2098,
+/**/
+    2097,
+/**/
+    2096,
+/**/
+    2095,
+/**/
+    2094,
+/**/
+    2093,
+/**/
+    2092,
+/**/
+    2091,
+/**/
+    2090,
+/**/
+    2089,
+/**/
+    2088,
+/**/
+    2087,
+/**/
+    2086,
+/**/
+    2085,
+/**/
+    2084,
+/**/
+    2083,
+/**/
+    2082,
+/**/
+    2081,
+/**/
+    2080,
+/**/
+    2079,
+/**/
+    2078,
+/**/
+    2077,
+/**/
+    2076,
+/**/
+    2075,
+/**/
+    2074,
+/**/
+    2073,
+/**/
+    2072,
+/**/
+    2071,
+/**/
+    2070,
+/**/
+    2069,
+/**/
+    2068,
+/**/
+    2067,
+/**/
+    2066,
+/**/
+    2065,
+/**/
+    2064,
+/**/
+    2063,
+/**/
+    2062,
+/**/
+    2061,
+/**/
+    2060,
+/**/
+    2059,
+/**/
+    2058,
+/**/
+    2057,
+/**/
+    2056,
+/**/
+    2055,
+/**/
+    2054,
+/**/
+    2053,
+/**/
+    2052,
+/**/
+    2051,
 /**/
     2050,
 /**/
@@ -5291,14 +5441,14 @@ list_version(void)
     version_msg(_("Compilation: "));
     version_msg((char *)all_cflags);
     version_msg("\n");
-#ifdef VMS
+# ifdef VMS
     if (*compiler_version != NUL)
     {
 	version_msg(_("Compiler: "));
 	version_msg((char *)compiler_version);
 	version_msg("\n");
     }
-#endif
+# endif
     version_msg(_("Linking: "));
     version_msg((char *)all_lflags);
 #endif
@@ -5368,9 +5518,9 @@ intro_message(
 	NULL,
 	NULL,
 	NULL,
-#ifdef MODIFIED_BY
+# ifdef MODIFIED_BY
 	NULL,
-#endif
+# endif
 	NULL,
 	NULL,
 	NULL,
